@@ -4,15 +4,18 @@ import tensorflow as tf
 class Sequence(tf.keras.layers.Layer):
     """
     Arguments:
-        name: str,
-        sequence: list of layers objects,
-        inputs: str: name of input pipe/connector | list: names of input pipes/connectors
+        name: str, positional arg
+        inputs: str: name of input pipe/connector | list: names of input pipes/connectors, positional arg
+        sequence=None: list of keras.layers objects,
         is_output_layer=False,
         trainable=True,
     Attributes:
-        _
+        inputs: str or list of input names.
+        sequence: list of keras.layers objects,
+        is_output_layer: True if this is the output Sequence of a Layer object.
     Methods:
-        _
+        call(x, training=False): by calling the sequence through __call__(), computes x.
+        self_build(): build the layers of the sequence into this Sequence object.
     """
 
     def __init__(self,
@@ -29,10 +32,10 @@ class Sequence(tf.keras.layers.Layer):
         self.inputs = inputs
         self.is_output_layer = is_output_layer
         if sequence is not None:
-            assert(type(sequence) == list), 'Please provide a sequence of one or more layers as a list'
+            assert(type(sequence) == list), 'Please provide a sequence of one or more keras.layers objects as a list'
         self.sequence = sequence
 
-    def __call__(self, x, training=False):
+    def call(self, x, training=False):
         for layer in self.sequence:
             x = layer(x, training=training)
         return x
